import {
  select,
  json,
  cluster,
  hierarchy,
  linkHorizontal,
  zoom,
  event,
  treemap
} from 'd3';

const svg = select('svg');
const width = document.body.clientWidth;
const height = document.body.clientHeight;

const margin = { top: 0, right: 300, bottom: 0, left: 75};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const treeLayout = cluster().size([innerHeight, innerWidth]);

const zoomG = svg
    .attr('width', width)
    .attr('height', height)
  .append('g');

const g = zoomG.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);

svg.call(zoom().on('zoom', () => {
  zoomG.attr('transform', event.transform);
}));

var changeColor = function(obj){
	const percent = Math.abs((obj.data.num_queries-100)/50)
  console.log(percent)
  return `hsl(50,100%,${percent}%)`
};

json('data.json')
  .then(data => {
  console.log(data)
    let root = hierarchy(data, d => d.children);
    root = treeLayout(root);
    let links = root.links();
    const linkPathGenerator = linkHorizontal()
      .x(d => d.y)
      .y(d => d.x);
  
    g.selectAll('path').data(links)
      .enter().append('path')
        .attr('d', linkPathGenerator);
  
    g.selectAll('text').data(root.descendants())
      .enter().append('text')
        .attr('x', d => d.children? d.y: d.y+50)
        .attr('y', d => d.x)
        .attr('dy', '0.32em')
        .attr('text-anchor', d => d.children? 'middle': 'right')
        .text(d => (d.height !== 0? d.data.predicate: ("rows:" + d.data.num_rows + "\n queries:" + d.data.num_queries)));
  
  let node = g.selectAll(".node")
    .data(root.descendants())
    .enter().append("g")
    .attr("class", d => "node" + (d.children ? " node--internal" : " node--leaf"))
    .attr("transform", d => "translate(" + d.y + "," + d.x + ")");
  
  node.append("circle").attr("r", d => d.data.num_rows !== undefined? d.data.num_rows/5000: 1 )
  .style("stroke", d => d.data.cached !== undefined? (d.data.cached === true? "red": "black"):"black")
  .style("stroke-width", d => d.data.cached !== undefined? (d.data.cached === true? 3: 1):1)
  .style("fill", d => d.data.cached !== undefined? changeColor(d):"black");
  });